==> edge-login-ui-rn-3.4.1.tgz: package/lib/components/abSpecific/UserListItem.js <==
import * as React from 'react';
import { TouchableOpacity } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import MaterialIcon from 'react-native-vector-icons/MaterialIcons';
import { lstrings } from '../../common/locales/strings';
import { useHandler } from '../../hooks/useHandler';
import { useTheme } from '../services/ThemeContext';
import { EdgeText } from '../themed/EdgeText';
export function UserListItem(props) {
    var _a;
    const { userInfo, onClick, onDelete, onLayout } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const handleDelete = useHandler(() => {
        onDelete(userInfo);
    });
    const handlePress = useHandler(() => {
        onClick(userInfo);
    });
    const username = (_a = userInfo.username) !== null && _a !== void 0 ? _a : lstrings.missing_username;
    return (React.createElement(TouchableOpacity, { accessible: false, style: styles.container, onPress: handlePress, onLayout: onLayout },
        React.createElement(EdgeText, { accessible: true, style: styles.text, numberOfLines: 2 }, username),
        React.createElement(TouchableOpacity, { style: styles.deleteButtonContainer, testID: `${username}.deleteIcon`, onPress: handleDelete },
            React.createElement(MaterialIcon, { style: styles.deleteButton, name: "close", size: theme.rem(1) }))));
}
const getStyles = cacheStyles((theme) => ({
    container: {
        backgroundColor: theme.modal,
        flex: 1,
        height: theme.rem(2.5),
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'space-between',
        width: '100%',
        paddingLeft: theme.rem(0.75)
    },
    text: {
        flex: 1,
        flexWrap: 'wrap',
        marginVertical: theme.rem(0.25)
    },
    deleteButtonContainer: {
        alignItems: 'center',
        flexDirection: 'row',
        justifyContent: 'center',
        minHeight: theme.rem(2),
        minWidth: theme.rem(2)
    },
    deleteButton: {
        color: theme.iconTappable
    }
}));

==> edge-login-ui-rn-3.17.0.tgz: package/lib/components/abSpecific/UserListItem.js <==
import * as React from 'react';
import { cacheStyles } from 'react-native-patina';
import MaterialIcon from 'react-native-vector-icons/MaterialIcons';
import { lstrings } from '../../common/locales/strings';
import { useHandler } from '../../hooks/useHandler';
import { EdgeTouchableOpacity } from '../common/EdgeTouchableOpacity';
import { useTheme } from '../services/ThemeContext';
import { EdgeText } from '../themed/EdgeText';
export function UserListItem(props) {
    var _a;
    const { userInfo, onClick, onDelete, onLayout } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const handleDelete = useHandler(() => {
        onDelete(userInfo);
    });
    const handlePress = useHandler(() => {
        onClick(userInfo);
    });
    const username = (_a = userInfo.username) !== null && _a !== void 0 ? _a : lstrings.missing_username;
    return (React.createElement(EdgeTouchableOpacity, { accessible: false, style: styles.container, onPress: handlePress, onLayout: onLayout },
        React.createElement(EdgeText, { accessible: true, style: styles.text, numberOfLines: 2 }, username),
        React.createElement(EdgeTouchableOpacity, { style: styles.deleteButtonContainer, testID: `${username}.deleteIcon`, onPress: handleDelete },
            React.createElement(MaterialIcon, { style: styles.deleteButton, name: "close", size: theme.rem(1) }))));
}
const getStyles = cacheStyles((theme) => ({
    container: {
        backgroundColor: theme.modal,
        flex: 1,
        height: theme.rem(2.5),
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'space-between',
        width: '100%',
        paddingLeft: theme.rem(0.75)
    },
    text: {
        flex: 1,
        flexWrap: 'wrap',
        marginVertical: theme.rem(0.25)
    },
    deleteButtonContainer: {
        alignItems: 'center',
        flexDirection: 'row',
        justifyContent: 'center',
        minHeight: theme.rem(2),
        minWidth: theme.rem(2)
    },
    deleteButton: {
        color: theme.iconTappable
    }
}));
